@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 
-# $Id: lamdaemon.pl,v 1.35 2006/04/27 14:43:52 gruberroland Exp $
+# $Id: lamdaemon.pl,v 1.37 2006/09/09 11:45:22 gruberroland Exp $
 #
 #  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 #  Copyright (C) 2003 - 2006  Tilo Lutz
@@ -96,15 +96,15 @@ if ($< == 0 ) { # we are root
 		}
 	else {
 		# loop for every transmitted user
-		my $string = do {local $/;<STDIN>};
-		@input = split ("\n", $string );
-		for ($i=0; $i<=$#input; $i++) {
+		while (1) {
+			my $input = <STDIN>;
+			chop($input);
 			$return = "";
-			@vals = split (' ', $input[$i]);
+			@vals = split (' ', $input);
 			switch: {
 				# Get user information
 				if (($vals[3] eq 'user') || ($vals[1] eq 'home')) { @user = getpwnam($vals[0]); }
-					else { @user = getgrnam($vals[0]); }
+				else { @user = getgrnam($vals[0]); }
 				$vals[1] eq 'home' && do {
 					switch2: {
 						$vals[2] eq 'add' && do {
@@ -113,44 +113,46 @@ if ($< == 0 ) { # we are root
 							$path =~ s,/(?:[^/]*)$,,;
 							($<, $>) = ($>, $<); # Get root privileges
 							if (! -e $path) {
-							    system 'mkdir', '-m', '0755', '-p', $path; # Create paths to homedir
-							    }
+								system 'mkdir', '-m', '0755', '-p', $path; # Create paths to homedir
+							}
 							if (! -e $user[7]) {
 								system 'mkdir', '-m', '0755', $user[7]; # Create homedir itself
 								system ("(cd /etc/skel && tar cf - .) | (cd $user[7] && tar xmf -)"); # Copy /etc/sekl into homedir
 								system 'chown', '-hR', "$user[2]:$user[3]" , $user[7]; # Change owner to new user
 								if (-e '/usr/sbin/useradd.local') {
 									system '/usr/sbin/useradd.local', $user[0]; # run useradd-script
-									}
 								}
+								$return = "Ok";
+							}
 							else {
-								$return = "ERROR,Lamdaemon,Homedirectory already exists.:$return";
-								}
+								$return = "ERROR,Lamdaemon,Home directory already exists.";
+							}
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
-							};
+						};
 						$vals[2] eq 'rem' && do {
 							($<, $>) = ($>, $<); # Get root previliges
 							if (-d $user[7] && $user[7] ne '/') {
-							    if ((stat($user[7]))[4] eq $user[2]) {
-								system 'rm', '-R', $user[7]; # Delete Homedirectory
-								if (-e '/usr/sbin/userdel.local') {
-									system '/usr/sbin/userdel.local', $user[0];
+								if ((stat($user[7]))[4] eq $user[2]) {
+									system 'rm', '-R', $user[7]; # Delete Homedirectory
+									if (-e '/usr/sbin/userdel.local') {
+										system '/usr/sbin/userdel.local', $user[0];
 									}
-							    }
-							    else {
-								$return = "ERROR,Lamdaemon,Homedirectory not owned by $user[2].:$return";
-							    }
+									$return = "Ok";
 								}
+								else {
+									$return = "ERROR,Lamdaemon,Home directory not owned by $user[2].";
+								}
+							}
 							else {
-								$return = "ERROR,Lamdaemon,Homedirectory doesn't exists.:$return";
+								$return = "ERROR,Lamdaemon,Home directory does not exist.";
 								}
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
 							};
+							# Show error if undfined command is used
+							$return = "ERROR,Lamdaemon,Unknown command $vals[2].";
 						}
-					# Show error if undfined command is used
-					$return = "ERROR,Lamdaemon,Unknown command $vals[2].:$return";
 					last switch;
 					};
 				$vals[1] eq 'quota' && do {
@@ -192,6 +194,9 @@ if ($< == 0 ) { # we are root
 							while ($quota_usr[$i][0]) {
 								$dev = Quota::getqcarg($quota[$i][0]);
 								$return = Quota::setqlim($dev,$user[2],$quota[$i][1],$quota[$i][2],$quota[$i][3],$quota[$i][4],1,$group);
+								if ($return == -1) {
+										$return = "ERROR,Lamdaemon,Unable to set quota!";
+									}
 								$i++;
 								}
 							($<, $>) = ($>, $<); # Give up root previleges
@@ -205,7 +210,12 @@ if ($< == 0 ) { # we are root
 									$dev = Quota::getqcarg($quota_usr[$i][1]);
 									@temp = Quota::query($dev,$user[2],$group);
 									if ($temp[0]ne'') {
-										$return = "$quota_usr[$i][1],$temp[0],$temp[1],$temp[2],$temp[3],$temp[4],$temp[5],$temp[6],$temp[7]:$return";
+										if ($temp == -1) {
+												$return = "ERROR,Lamdaemon,Unable to read quota!";
+											}
+										else {
+											$return = "$quota_usr[$i][1],$temp[0],$temp[1],$temp[2],$temp[3],$temp[4],$temp[5],$temp[6],$temp[7]:$return";
+											}
 										}
 									else { $return = "$quota_usr[$i][1],0,0,0,0,0,0,0,0:$return"; }
 									}
@@ -215,56 +225,16 @@ if ($< == 0 ) { # we are root
 							($<, $>) = ($>, $<); # Give up root previleges
 							last switch2;
 							};
-						$return = "ERROR,Lamdaemon,Unknown command $vals[2].:$return";
+						$return = "ERROR,Lamdaemon,Unknown command $vals[2].";
 						}
 					};
 					last switch;
-				$return = "ERROR,Lamdaemon,Unknown command $vals[1].:$return";
+				$return = "ERROR,Lamdaemon,Unknown command $vals[1].";
 				};
 				print "$return\n";
 			}
 		}
 	}
 else {
-	$hostname = shift @ARGV;
-	$remotepath = shift @ARGV;
-	use Net::SSH::Perl;
-	if ($ARGV[2] eq "*test") { print "Net::SSH::Perl successfully installed.\n"; }
-	if (($ARGV[0] eq "-") and ($ARGV[1] eq "-")) {  # user+passwd are in STDIN
-		$username = <STDIN>;
-		chop($username);
-		@username = split (',', $username);
-		$username[0] =~ s/uid=//;
-		$username[0] =~ s/cn=//;
-		$username = $username[0];
-		$password = <STDIN>;
-		chop($password);
-	}
-	else {
-		@username = split (',', $ARGV[0]);
-		$username[0] =~ s/uid=//;
-		$username[0] =~ s/cn=//;
-		$username = $username[0];
-		$password = $ARGV[1];
-	}
-	# Put all transfered lines in one string
-	if ($ARGV[2] ne "*test") {
-		$string = do {local $/;<STDIN>};
-		}
-	else {
-		$argv = "*test\n";
-		$string = " \n";
-	}
-	my $ssh = Net::SSH::Perl->new($hostname, options=>[
-		"UserKnownHostsFile /dev/null"],
-		protocol => "2,1", debug => 0 );
-	$ssh->login($username, $password);
-	# Change needed to prevent buffer overrun
-	@string2 = split ("\n", $string);
-	for ($i=0; $i<=$#string2; $i++) {
-		($stdout2, $stderr, $exit) = $ssh->cmd("sudo $remotepath $argv", $string2[$i]);
-		$stdout .= $stdout2;
-		}
-	#($stdout, $stderr, $exit) = $ssh->cmd("sudo $remotepath $argv", $string);
-	print $stdout;
-	}
+	print "ERROR,Lamdaemon,Not called as root!\n";
+}
