@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.76 2006/04/16 12:43:53 gruberroland Exp $
+$Id: confmain.php,v 1.79 2006/09/24 14:19:50 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -56,7 +56,7 @@ if (! $passwd) {
 }
 
 if (!isset($_SESSION['conf_config']) && isset($_POST['filename'])) {
-	$_SESSION['conf_config'] = new Config($_POST['filename']);	
+	$_SESSION['conf_config'] = new LAMConfig($_POST['filename']);
 }
 $conf = &$_SESSION['conf_config'];
 
@@ -102,7 +102,7 @@ if (isset($_GET["typesback"])) {
 	// check if a new account type was added
 	if (isset($_GET["typeschanged"])) {
 		metaRefresh("confmodules.php");
-		exit;		
+		exit;
 	}
 }
 
@@ -358,7 +358,7 @@ echo ("<tr><td colspan=3>&nbsp;</td></tr>\n");
 
 // new password
 echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
-	_("New Password") . ": </b></font></td>".
+	_("New password") . ": </b></font></td>".
 	"<td align=\"left\"><input tabindex=\"$tabindex\" type=\"password\" name=\"passwd1\"></td>\n");
 $tabindex++;
 echo "<td rowspan=2>";
@@ -368,7 +368,7 @@ echo "</a>\n";
 echo "</td></tr>\n";
 // reenter password
 echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
-	_("Reenter Password") . ": </b></font></td>".
+	_("Reenter password") . ": </b></font></td>".
 	"<td align=\"left\"><input tabindex=\"$tabindex\" type=\"password\" name=\"passwd2\"></td></tr>\n");
 $tabindex++;
 echo ("</table>\n");
@@ -411,7 +411,7 @@ echo ("</html>\n");
 function saveSettings() {
 	$conf = &$_SESSION['conf_config'];
 	$types = $conf->get_ActiveTypes();
-	
+
 	// remove double slashes if magic quotes are on
 	if (get_magic_quotes_gpc() == 1) {
 		$postKeys = array_keys($_POST);
@@ -422,7 +422,7 @@ function saveSettings() {
 	// check new preferences
 	$errors = array();
 	if (!$conf->set_ServerURL($_POST['serverurl'])) {
-		$errors[] = array("ERROR", _("Server Address is empty!"));
+		$errors[] = array("ERROR", _("Server address is invalid!"));
 	}
 	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
@@ -505,7 +505,7 @@ function saveSettings() {
 			"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr><br><br>");
 		$conf->set_moduleSettings($options);
 		$conf->save();
-		echo ("<br><br><br><br><br><a href=\"../login.php\" target=\"_top\">" . _("Back to Login") . "</a>");	
+		echo ("<br><br><br><br><br><a href=\"../login.php\" target=\"_top\">" . _("Back to Login") . "</a>");
 		echo("</body></html>");
 		// remove settings from session
 		$sessionKeys = array_keys($_SESSION);
