@@ -1,24 +1,24 @@
 <?php
 /*
-	$Id: delete.php,v 1.55 2006/05/16 15:18:24 gruberroland Exp $
-	
+	$Id: delete.php,v 1.58 2006/10/22 07:44:01 gruberroland Exp $
+
 	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
 	Copyright (C) 2003 - 2006  Tilo Lutz
-	
+
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation; either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-	
+
 */
 
 /**
@@ -71,9 +71,7 @@ if ($_GET['type']) {
 	$_SESSION['account'] = new accountContainer($_GET['type'], 'account');
 	// Show HTML Page
 	echo $_SESSION['header'];
-	echo "<title>";
-	echo _("Delete Account");
-	echo "</title>\n";
+	echo "<title>LDAP Account Manager</title>\n";
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
 	echo "</head><body>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
@@ -124,9 +122,7 @@ if ($_POST['cancel']) {
 if ($_POST['delete']) {
 	// Show HTML Page
 	echo $_SESSION['header'];
-	echo "<title>";
-	echo _("Delete Account");
-	echo "</title>\n";
+	echo "<title>LDAP Account Manager</title>\n";
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
 	echo "</head><body>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
@@ -148,7 +144,7 @@ if ($_POST['delete']) {
 		// load attributes
 		foreach ($module as $singlemodule) {
 			// load changes
-			$temp = $_SESSION['account']->module[$singlemodule]->delete_attributes($_POST);
+			$temp = $_SESSION['account']->module[$singlemodule]->delete_attributes();
 			if (is_array($temp)) {
 				// merge changes
 				$DNs = array_keys($temp);
@@ -205,6 +201,7 @@ if ($_POST['delete']) {
 				if (!is_array($result)) continue;
 				// check for error somewhere in lamdaemon
 				foreach ($result as $singleresult) {
+					$singleresult = explode(",", $singleresult);
 					if (is_array($singleresult)) {
 						if ($singleresult[0] == 'ERROR') {
 							$stopprocessing = true;
@@ -260,7 +257,7 @@ function getChildCount($dn) {
 
 /**
 * Deletes a DN and all child entries.
-* 
+*
 * @param string $dn DN to delete
 * @return array error messages
 */
