@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: initsuff.php,v 1.13 2005/01/22 11:05:44 gruberroland Exp $
+$Id: initsuff.php,v 1.15 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,16 +28,17 @@ $Id: initsuff.php,v 1.13 2005/01/22 11:05:44 gruberroland Exp $
 * @package main
 */
 
+/** security functions */
+include_once("../lib/security.inc");
 /** access to configuration settings */
-include_once ("../lib/config.inc");
+include_once("../lib/config.inc");
 /** LDAP access */
-include_once ("../lib/ldap.inc");
+include_once("../lib/ldap.inc");
 /** status messages */
-include_once ("../lib/status.inc");
+include_once("../lib/status.inc");
 
 // start session
-session_save_path("../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
