@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: userlink.php,v 1.14 2005/03/10 20:19:56 gruberroland Exp $
+$Id: userlink.php,v 1.17 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,14 +30,15 @@ $Id: userlink.php,v 1.14 2005/03/10 20:19:56 gruberroland Exp $
 * @author Roland Gruber
 */
 
+/** security functions */
+include_once("../../lib/security.inc");
 /** Needed to find DNs of users */
-include_once ("../../lib/ldap.inc");
+include_once("../../lib/ldap.inc");
 /** Used to display error messages */
-include_once ("../../lib/status.inc");
+include_once("../../lib/status.inc");
 
 // start session
-session_save_path("../../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
@@ -62,7 +63,7 @@ else {
 	echo "</head><body>\n";
 	StatusMessage("ERROR", "", _("This user was not found!") . " (" . $user . ")");
 	echo "<p>&nbsp;</p>";
-	echo "<p><a href=\"listgroups.php\">" . _("Back to group list") . "</a></p>";
+	echo "<p><a href=\"list.php?type=group\">" . _("Back to group list") . "</a></p>";
 	echo ("</body></html>\n");
 }
 
