@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.93 2006/05/23 14:46:58 gruberroland Exp $
+$Id: login.php,v 1.97 2006/10/18 16:08:58 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -32,6 +32,8 @@ $Id: login.php,v 1.93 2006/05/23 14:46:58 gruberroland Exp $
 include_once("../lib/status.inc");
 /** security functions */
 include_once("../lib/security.inc");
+/** self service functions */
+include_once("../lib/selfService.inc");
 
 // check environment
 $criticalErrors = array();
@@ -59,6 +61,10 @@ for ($i = 0; $i < sizeof($writableDirs); $i++) {
 		$criticalErrors[] = array("ERROR", 'The directory %s is not writable for the web server. Please change your file permissions.', '', array($path));
 	}
 }
+// check session auto start
+if (ini_get("session.auto_start") == "1") {
+	$criticalErrors[] = array("ERROR", "Please deactivate session.auto_start in your php.ini. LAM will not work if it is activated.");
+}
 // stop login if critical errors occured
 if (sizeof($criticalErrors) > 0) {
 	echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
@@ -170,7 +176,14 @@ function display_LoginPage($config_object) {
 		</p>
 		<table width="100%" border="0">
 			<tr>
-				<td width="100%" align="right">
+				<TD width="50%" align="left">
+					<?PHP
+						if (!isLAMProVersion()) {
+							echo "<a href=\"http://lam.sourceforge.net/lamPro/index.htm\">" . _("Want more features? Get LAM Pro!") . "</a>";
+						}
+					?>
+				</TD>
+				<td width="50%" align="right">
 					<a href="./config/index.php"><IMG alt="configuration" src="../graphics/tools.png">&nbsp;<?php echo _("LAM configuration") ?></a>
 				</td>
 			</tr>
@@ -181,7 +194,7 @@ function display_LoginPage($config_object) {
 		$extList = getRequiredExtensions();
 		for ($i = 0; $i < sizeof($extList); $i++) {
 			if (!extension_loaded($extList[$i])) {
-				StatusMessage("ERROR", _("A required PHP extension is missing!"), $extList[$i]);
+				StatusMessage("ERROR", "A required PHP extension is missing!", $extList[$i]);
 				echo "<br>";
 			}
 		}
@@ -331,7 +344,12 @@ function display_LoginPage($config_object) {
 				<TR><TD align="right"><HR>
 					<SMALL>
 					<?php
-						echo "LDAP Account Manager: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+						if (isLAMProVersion()) {
+							echo "LDAP Account Manager <b>Pro</b>: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+						}
+						else {
+							echo "LDAP Account Manager: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+						}
 					?>
 					</SMALL>
 				</TD></TR>
@@ -408,16 +426,16 @@ if(!empty($_POST['checklogin']))
 }
 // Reload loginpage after a profile change
 elseif(!empty($_POST['profileChange'])) {
-	$_SESSION['config'] = new Config($_POST['profile']); // Recreate the config object with the submited
+	$_SESSION['config'] = new LAMConfig($_POST['profile']); // Recreate the config object with the submited
 	display_LoginPage($_SESSION['config']); // Load login page
 }
 // Load login page
 else
 {
 	$_SESSION['loggedIn'] = false;
-	$default_Config = new CfgMain();
+	$default_Config = new LAMCfgMain();
 	$default_Profile = $default_Config->default;
-	$_SESSION["config"] = new Config($default_Profile); // Create new Config object
+	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
 	$_SESSION["cfgMain"] = $default_Config; // Create new CfgMain object
 
 	display_LoginPage($_SESSION["config"]); // Load Login page
