@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.6 2005/08/04 15:14:44 gruberroland Exp $
+$Id: massDoUpload.php,v 1.9 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2004  Roland Gruber
+  Copyright (C) 2004 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ $Id: massDoUpload.php,v 1.6 2005/08/04 15:14:44 gruberroland Exp $
 * @package tools
 */
 
+/** security functions */
+include_once("../lib/security.inc");
 /** access to configuration */
 include_once('../lib/config.inc');
 /** LDAP handle */
@@ -41,8 +43,7 @@ include_once('../lib/cache.inc');
 
 
 // Start session
-session_save_path('../sess');
-@session_start();
+startSecureSession();
 
 // Redirect to startpage if user is not loged in
 if (!isset($_SESSION['loggedIn'])) {
@@ -63,6 +64,7 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 	$startTime = time();
 	$maxTime = get_cfg_var('max_execution_time') - 5;
 	if ($maxTime > 60) $maxTime = 60;
+	if ($maxTime <= 0) $maxTime = 60;
 	$refreshTime = $maxTime + 7;
 	echo "<meta http-equiv=\"refresh\" content=\"" . $refreshTime . "; URL=massDoUpload.php\">\n";
 	echo "</head>\n<body>\n";
