@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: pdfpage.php,v 1.17 2005/07/27 18:27:24 gruberroland Exp $
+$Id: pdfpage.php,v 1.20 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Michael Drgner
+  Copyright (C) 2003 - 2006  Michael Drgner
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@ $Id: pdfpage.php,v 1.17 2005/07/27 18:27:24 gruberroland Exp $
 * @package PDF
 */
 
+/** security functions */
+include_once("../../lib/security.inc");
 /** access to PDF configuration files */
 include_once('../../lib/pdfstruct.inc');
 /** LDAP object */
@@ -43,8 +45,7 @@ include_once('../../lib/modules.inc');
 include_once('../../lib/xml_parser.inc');
 
 // start session
-session_save_path("../../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
@@ -732,7 +733,7 @@ foreach($_SESSION['availablePDFFields'] as $module => $fields) {
 					<td colspan="3">
 						<fieldset>
 							<legend>
-								<b><?php echo _("Submit"); ?></b>
+								<b><?php echo _("Save"); ?></b>
 							</legend>
 							<table border="0" align="left">
 							<?php
@@ -769,7 +770,7 @@ foreach($_SESSION['availablePDFFields'] as $module => $fields) {
 										<input type="submit" name="submit" value="<?php echo _("Save");?>">
 									</td>
 									<td>
-										<input type="submit" name="abort" value="<?php echo _("Abort");?>">
+										<input type="submit" name="abort" value="<?php echo _("Cancel");?>">
 									</td>
 									<td>
 										&nbsp
