@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profiledelete.php,v 1.15 2004/12/12 11:27:57 gruberroland Exp $
+$Id: profiledelete.php,v 1.20 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ $Id: profiledelete.php,v 1.15 2004/12/12 11:27:57 gruberroland Exp $
 * @author Roland Gruber
 */
 
+/** security functions */
+include_once("../../lib/security.inc");
 /** helper functions for profiles */
 include_once("../../lib/profiles.inc");
 /** access to LDAP server */
@@ -36,8 +38,7 @@ include_once("../../lib/ldap.inc");
 include_once("../../lib/config.inc");
 
 // start session
-session_save_path("../../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
@@ -60,7 +61,7 @@ if ($_POST['submit']) {
 		StatusMessage("ERROR", _("Unable to delete profile!"), $_POST['del'] . "." . $_POST['type']);
 	}
 	else StatusMessage("INFO", _("Deleted profile:"), $_POST['del'] . "." . $_POST['type']);
-	echo ("<br><a href=\"profilemain.php\">" . _("Back to Profile Editor") . "</a>");
+	echo ("<br><a href=\"profilemain.php\">" . _("Back to profile editor") . "</a>");
 	echo ("</body></html>\n");
 	exit;
 }
@@ -68,27 +69,18 @@ if ($_POST['submit']) {
 // check if admin has aborted delete operation
 if ($_POST['abort']) {
 	StatusMessage("INFO", "", _("Delete operation canceled."));
-	echo ("<br><a href=\"profilemain.php\">" . _("Back to Profile Editor") . "</a>");
+	echo ("<br><a href=\"profilemain.php\">" . _("Back to profile editor") . "</a>");
 	echo ("</body></html>\n");
 	exit;
 }
 
-// check if right type was given
 $type = $_GET['type'];
-if (($type == "user") || ($type == "host") || ($type == "group")) {
-	// user profile
-	echo ("<p align=\"center\"><big>" . _("Do you really want to delete this profile?") . " <b>");
-	echo ($_GET['del'] . "</b></big><br></p>\n");
-	echo ("<form action=\"profiledelete.php\" method=\"post\">\n");
-	echo ("<p align=\"center\">\n");
-	echo ("<input type=\"submit\" name=\"submit\" value=\"" . _("Submit") . "\">\n");
-	echo ("<input type=\"submit\" name=\"abort\" value=\"" . _("Abort") . "\">\n");
-	echo ("<input type=\"hidden\" name=\"type\" value=\"$type\">");
-	echo ("<input type=\"hidden\" name=\"del\" value=\"" . $_GET['del'] . "\">");
-	echo ("</p></form></body></html>\n");
-}
-else{
-	// no valid profile type
-	StatusMessage("ERROR", "", _("Wrong or missing type!") . " " . $type);
-	echo ("<a href=\"profilemain.php\">" . _("Back to Profile Editor") . "</a>");
-}
+echo ("<p align=\"center\"><big>" . _("Do you really want to delete this profile?") . " <b>");
+echo ($_GET['del'] . "</b></big><br></p>\n");
+echo ("<form action=\"profiledelete.php\" method=\"post\">\n");
+echo ("<p align=\"center\">\n");
+echo ("<input type=\"submit\" name=\"submit\" value=\"" . _("Ok") . "\">\n");
+echo ("<input type=\"submit\" name=\"abort\" value=\"" . _("Cancel") . "\">\n");
+echo ("<input type=\"hidden\" name=\"type\" value=\"$type\">");
+echo ("<input type=\"hidden\" name=\"del\" value=\"" . $_GET['del'] . "\">");
+echo ("</p></form></body></html>\n");
