@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profilepage.php,v 1.23 2005/07/12 15:52:15 gruberroland Exp $
+$Id: profilepage.php,v 1.30 2006/03/26 17:51:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003  Roland Gruber
+  Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ $Id: profilepage.php,v 1.23 2005/07/12 15:52:15 gruberroland Exp $
 * @author Roland Gruber
 */
 
+/** security functions */
+include_once("../../lib/security.inc");
 /** helper functions for profiles */
 include_once("../../lib/profiles.inc");
 /** access to LDAP server */
@@ -40,8 +42,7 @@ include_once("../../lib/modules.inc");
 include_once("../../lib/status.inc");
 
 // start session
-session_save_path("../../sess");
-@session_start();
+startSecureSession();
 
 setlanguage();
 
@@ -57,7 +58,7 @@ if (isset($_POST['accounttype'])) $_GET['type'] = $_POST['accounttype'];
 
 // abort button was pressed
 // back to profile editor
-if ($_POST['abort']) {
+if (isset($_POST['abort'])) {
 	metaRefresh("profilemain.php");
 	exit;
 }
@@ -65,10 +66,11 @@ if ($_POST['abort']) {
 // print header
 echo $_SESSION['header'];
 echo "<title></title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
+echo "<title></title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_GET['type'] . ".css\">\n";
 echo "</head><body><br>\n";
 
 // save button was presed
-if ($_POST['save']) {
+if (isset($_POST['save'])) {
 	// create option array to check and save
 	$options = array();
 	$opt_keys = array_keys($_SESSION['profile_types']);
@@ -79,7 +81,7 @@ if ($_POST['save']) {
 		}
 		// checkboxes
 		elseif ($_SESSION['profile_types'][$element] == "checkbox") {
-			if ($_POST[$element] == "on") $options[$element] = array('true');
+			if (isset($_POST[$element]) && ($_POST[$element] == "on")) $options[$element] = array('true');
 			else $options[$element] = array('false');
 		}
 		// dropdownbox
@@ -88,14 +90,15 @@ if ($_POST['save']) {
 		}
 		// multiselect
 		elseif ($_SESSION['profile_types'][$element] == "multiselect") {
-			$options[$element] = $_POST[$element];  // value is already an array
+			if (isset($_POST[$element])) $options[$element] = $_POST[$element];  // value is already an array
+			else $options[$element] = array();
 		}
 	}
 	
 	// remove double slashes if magic quotes are on
 	if (get_magic_quotes_gpc() == 1) {
 		foreach ($opt_keys as $element) {
-			if (is_string($options[$element][0])) $options[$element][0] = stripslashes($options[$element][0]);
+			if (isset($options[$element][0]) && is_string($options[$element][0])) $options[$element][0] = stripslashes($options[$element][0]);
 		}
 	}
 	
@@ -117,7 +120,7 @@ if ($_POST['save']) {
 		// save profile
 		if (saveAccountProfile($options, $_POST['profname'], $_POST['accounttype'])) {
 			echo StatusMessage("INFO", _("Profile was saved."), $_POST['profname']);
-			echo ("<br><p><a href=\"profilemain.php\">" . _("Back to Profile Editor") . "</a></p>");
+			echo ("<br><p><a href=\"profilemain.php\">" . _("Back to profile editor") . "</a></p>");
 			echo "</body></html>";
 			exit();
 		}
@@ -130,7 +133,6 @@ $_SESSION['profile_types'] = array();
 
 // check if account type is valid
 $type = $_GET['type'];
-if (!(($type == 'user') || ($type == 'group') || ($type == 'host'))) meta_refresh('profilemain.php');
 
 // get module options
 $options = getProfileOptions($type);
@@ -141,7 +143,12 @@ if (isset($_POST['save'])) {
 	$postKeys = array_keys($_POST);
 	for ($i = 0; $i < sizeof($postKeys); $i++) {
 		if (!is_array($_POST[$postKeys[$i]])) {
-			$old_options[$postKeys[$i]] = array($_POST[$postKeys[$i]]);
+			if (get_magic_quotes_gpc() == 1) {
+				$old_options[$postKeys[$i]] = array(stripslashes($_POST[$postKeys[$i]]));
+			}
+			else {
+				$old_options[$postKeys[$i]] = array($_POST[$postKeys[$i]]);
+			}
 		}
 		else {
 			$old_options[$postKeys[$i]] = $_POST[$postKeys[$i]];
@@ -174,7 +181,7 @@ echo "<fieldset class=\"" . $type . "edit\">\n<legend><b>" . _("LDAP") . "</b></
 	echo "</td><td>";
 	echo "<select name=\"ldap_suffix\" tabindex=\"1\">";
 	for ($i = 0; $i < sizeof($suffixes); $i++) {
-		if ($old_options['ldap_suffix'][0] == $suffixes[$i]) {
+		if (isset($old_options['ldap_suffix']) && ($old_options['ldap_suffix'][0] == $suffixes[$i])) {
 			echo "<option selected>" . $suffixes[$i] . "</option>\n";
 		}
 		else {
@@ -194,7 +201,7 @@ echo "<fieldset class=\"" . $type . "edit\">\n<legend><b>" . _("LDAP") . "</b></
 	echo "</td><td>";
 	echo "<select name=\"ldap_rdn\" tabindex=\"1\">";
 	for ($i = 0; $i < sizeof($rdns); $i++) {
-		if ($old_options['ldap_rdn'][0] == $rdns[$i]) {
+		if (isset($old_options['ldap_rdn']) && ($old_options['ldap_rdn'][0] == $rdns[$i])) {
 			echo "<option selected>" . $rdns[$i] . "</option>\n";
 		}
 		else {
@@ -243,7 +250,7 @@ echo ("<input tabindex=\"$tabindex\" type=\"submit\" name=\"save\" value=\"" . _
 $tabindex++;
 echo ("<input tabindex=\"$tabindex\" type=\"reset\" name=\"reset\" value=\"" . _("Reset") . "\">\n");
 $tabindex++;
-echo ("<input tabindex=\"$tabindex\" type=\"submit\" name=\"abort\" value=\"" . _("Abort") . "\">\n");
+echo ("<input tabindex=\"$tabindex\" type=\"submit\" name=\"abort\" value=\"" . _("Cancel") . "\">\n");
 echo "<input type=\"hidden\" name=\"accounttype\" value=\"$type\">\n";
 
 echo ("</form></body></html>\n");
