@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: tools.php,v 1.7 2006/03/26 17:51:25 gruberroland Exp $
+$Id: tools.php,v 1.8 2006/10/04 18:12:22 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Roland Gruber
@@ -85,6 +85,13 @@ $tools[] = array(
 		"link" => "schema/schema.php"
 	);
 
+// tests
+$tools[] = array(
+		"name" => _("Tests"),
+		"description" => _("Here you can test if certain LAM features work on your installation."),
+		"link" => "tests/index.php"
+	);
+
 echo "<p>&nbsp;</p>\n";
 
 // print tools table
